package MT::Plugins::CommentIcon;

use strict;
use warnings;
use MT::Template::Context;

use XML::RSS;
use XML::FOAF;
use File::Spec;
use LWP::Simple qw(get);
use HTML::RSSAutodiscovery;
use File::Temp qw(tempfile);
use Image::Magick::Thumbnail;

our $VERSION	= '1.000';

use constant THUMB_SIZE => 64;

MT::Template::Context->add_tag( CommentAuthorIcon => sub {
	my $ctx		= shift;
	my $args	= shift;
	my $comment	= $ctx->stash( 'comment' );
	my $url		= $comment->url();
	if ($url) {
		return geticonfrom( $url, $ctx );
	} else {
		return '';
	}
} );

sub geticonfrom {
	my $url		= shift;
	my $ctx		= shift;
	my $blog	= $ctx->stash( 'blog' );
	my $imagename	= $url;
	$imagename	=~ s#^[^:]+://##;
	$imagename	=~ tr#/#_#;
	my $imagefile	= File::Spec->catfile( $blog->archive_path, 'people', "${imagename}.jpg" );
	if (-r $imagefile) {
		my ($href, $title, $width, $height);
		my $img	= $blog->archive_url . "people/${imagename}.jpg";
                return img_html($img, $href, $width, $height, $title);
	} else {
                my $foaf    = new XML::FOAF ( new URI $url );
                if (ref($foaf)) {
                    my $person  = $foaf->person;
                    my $depict  = $person->depiction;
                    if ($depict) {
			my $thumbfile	= File::Spec->catfile( $blog->archive_path, 'people', $imagename . ".jpg" );
			my ($w, $h)	= make_thumbnail( $depict, $thumbfile );
			my $img	= $blog->archive_url . "people/${imagename}.jpg";
                        return img_html( $img, $person->weblog, $w, $h );
                    }
                }

		my $parser  = new HTML::RSSAutodiscovery;
		my $feeds	= eval { $parser->parse( $url ) };
		if ($@) {
			warn $@;
			return '';
		}
		if (ref($feeds) and scalar(@{$feeds})) {
			foreach my $feed (@{ $feeds }) {
				my $rssparser   = new XML::RSS;
				next unless ($feed->{'type'} eq 'application/rss+xml');
				my $feedurl = $feed->{'href'};
				unless ($feedurl =~ m(^[^:]+://|^/)) {
					$url    =~ s#/[^/]*$#/#;
					$feedurl    = $url . $feedurl;
				}
				my $rss	= get( $feedurl ) || next;
				eval { $rssparser->parse( $rss ) or next; };
				if ($@) {
					warn $@;
					return '';
				}
				if (exists $rssparser->{'image'}) {
					my $href    = $rssparser->{'image'}{ 'link' };
					my $imgurl  = $rssparser->{'image'}{ 'url' };
					my $width   = $rssparser->{'image'}{ 'width' };
					my $height  = $rssparser->{'image'}{ 'height' };
					my $title   = $rssparser->{'image'}{ 'title' };
					next unless ($imgurl);
				
					# add image to cache
					my $thumbfile	= File::Spec->catfile( $blog->archive_path, 'people', $imagename . ".jpg" );
					($width,$height)	= make_thumbnail( $imgurl, $thumbfile ) or next;
					my $img	= $blog->archive_url . "people/${imagename}.jpg";
				
                                        return img_html($img, $href, $width, $height, $title);
				}
			}
		}
	}
	return '';
}

sub make_thumbnail {
	my $img		= shift;
	my $thumbfile	= shift;
	my ($fh,$imgfile)	= tempfile();
	unless (-w $imgfile) {
		warn $!;
		return 0;
	}

	my ($thumb,$x,$y);
	eval {
		# open( my $fh, ">$imagefile" ) or do { warn $!; return 0 };
		my $imgdata	= get( $img );
		print { $fh } $imgdata;
		close( $fh );
		my $src	= new Image::Magick || die $!;
		$src->Read( $imgfile );
		($thumb,$x,$y)	= Image::Magick::Thumbnail::create($src,THUMB_SIZE);
		$thumb->[0]->Write($thumbfile);
	};
	unlink( $imgfile );
	if ($@) {
		warn $@;
		return 0;
	} else {
		return ($x, $y);
	}
}

sub img_html {
    my ($img, $href, $width, $height, $title)   = @_;
    $title	||= '';
    my $html    = qq|<div class="commenticon">|
                . ($href ? qq|<a href="${href}"| : '')
                . (($href && $title) ? qq| title="${title}"| : '')
                . ($href ? qq|>| : '')
                . qq|<img src="${img}" |
                . qq|alt="${title}" |
                . ($width ? qq|width="${width}" | : '')
                . ($height ? qq|height="${height}" | : '')
                . qq| />|
                . ($href ? qq|</a>| : '')
                . qq|</div>|;
    return $html;
}

1;

__END__
